@@ -48,8 +48,6 @@ pub mod janus_edge_stream_request;
 pub use self::janus_edge_stream_request::JanusEdgeStreamRequest;
 pub mod janus_stream;
 pub use self::janus_stream::JanusStream;
-pub mod janus_stream_request;
-pub use self::janus_stream_request::JanusStreamRequest;
 pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod octo_print_backup;
